# Voronoiville

Fast Voronoi diagrams in Python written in Rust, thanks to the [`voronoice`](https://crates.io/crates/voronoice) crate, [`PyO3`](https://pyo3.rs/), and [Maturin](https://maturin.rs/).


Resources:
- https://douglasduhaime.com/posts/lloyd-iteration.html